@@ -36,7 +36,9 @@ __all__ = (
     "ProvisioningStatusType",
     "StatusValuesType",
     "TargetTypeType",
+    "SSOAdminServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -71,6 +73,7 @@ ProvisioningStatusType = Literal[
 ]
 StatusValuesType = Literal["FAILED", "IN_PROGRESS", "SUCCEEDED"]
 TargetTypeType = Literal["AWS_ACCOUNT"]
+SSOAdminServiceName = Literal["sso-admin"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -102,6 +105,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -224,6 +228,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -372,6 +377,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_account_assignment_creation_status",
     "list_account_assignment_deletion_status",
